@@ -36,7 +36,7 @@ test_that("gradient of gr_clust_multi_GP() works for
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "SE", "SE",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
@@ -92,7 +92,7 @@ test_that("gradient of gr_clust_multi_GP() works for the Linear kernel", {
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "LIN", "LIN",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
@@ -149,7 +149,7 @@ test_that("gradient of gr_clust_multi_GP() works for the Periodic kernel", {
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "PERIO", "PERIO",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
@@ -226,7 +226,7 @@ test_that("gradient of gr_clust_multi_GP() works
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "RQ", "RQ",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
@@ -303,7 +303,7 @@ test_that("gradient of gr_GP_mod_common_hp_k()
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "SE", "SE",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   hp_i_1 <- hp_i %>%
@@ -364,7 +364,7 @@ test_that("gradient of gr_GP_mod_common_hp_k() works for the Linear kernel", {
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "LIN", "LIN",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- mu_k_param$mean
@@ -433,7 +433,7 @@ test_that("gradient of gr_GP_mod_common_hp_k()
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "PERIO", "PERIO",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- mu_k_param$mean
@@ -509,7 +509,7 @@ test_that("gradient of gr_GP_mod_common_hp_k()
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "RQ", "RQ",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture,2, 0.001
   )
 
   db_1 <- mu_k_param$mean
@@ -585,7 +585,7 @@ test_that("gradient of gr_clust_multi_GP_common_hp_i()
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "SE", "SE", hp_k, hp_i,
-    old_hp_mixture, 0.001
+    old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
@@ -656,7 +656,7 @@ test_that("gradient of gr_clust_multi_GP_common_hp_i()
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "LIN", "LIN",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
@@ -731,7 +731,7 @@ test_that("gradient of gr_clust_multi_GP_common_hp_i()
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "PERIO", "PERIO",
-    hp_k, hp_i, old_hp_mixture, 0.001
+    hp_k, hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
@@ -817,7 +817,7 @@ test_that("gradient of gr_clust_multi_GP_common_hp_i()
 
   mu_k_param <- MagmaClustR:::ve_step(
     db, m_k, "RQ", "RQ", hp_k,
-    hp_i, old_hp_mixture, 0.001
+    hp_i, old_hp_mixture, 2, 0.001
   )
 
   db_1 <- db %>% dplyr::filter(.data$ID == 1)
